@@ -12,7 +12,7 @@ $TIMEFORMAT  = ($TIMEFORMAT  or "%Y-%m-%d/%H:%M:%S %z")
 
 $USEBACKUP   = (defined?($USEBACKUP) ? $USEBACKUP : true)
 $USERSS      = (defined?($USERSS)    ? $USERSS    : true)
-$USEATTACH   = (defined?($USEATTACH) ? $USEATTACH : true)
+$USEATTACH   = (defined?($USEATTACH) ? $USEATTACH : false)
 
 $ATTACH_SIZE_LIMIT = ($ATTACH_SIZE_LIMIT or  1024 * 1024 * 10)
 
@@ -34,5 +34,14 @@ $metapages = {
   'NotCreatedPages' => '#notcreatedpages',
   'PluginList' => '#pluginlist',
   'ReverseLinkList' => '#reverselinklist',
+  'SearchPage' => '#search',
 }
 
+
+$plugin_list = ($plugin_list or [
+  '2chbbs.rb',
+#  'attach.rb',
+  'core.rb',
+  'demo.rb',
+#  'search.rb',
+])
